/*
 * Copyright (C) 2023 neocotic
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

/* istanbul ignore file */

/**
 * Contains contextual information that is based on configuration data that can also be run to achieve a result.
 *
 * @public
 * @abstract
 */
export class Context {

  /**
   * @type {Config}
   * @private
   */
  #config;

  /**
   * Creates an instance of {@link Context} with the specified <code>config</code>.
   *
   * @param {Config} config - the {@link Config} to be used
   * @protected
   */
  constructor(config) {
    this.#config = config;
  }

  /**
   * Returns the configuration associated with this {@link Context}.
   *
   * @return {Config} The associated {@link Config}.
   * @public
   */
  get config() {
    return this.#config;
  }

}
